* ------------------------------------------------------------------------------
*
*           THE ECONOMICS OF WOMEN'S RIGHTS  - Extended Data Set 
*                  
* ------------------------------------------------------------------------------
*
* by Michèle Tertilt, Matthias Doepke, Anne Hannusch and Laura Montenbruck
*
* This version: 2023-01-15
*
* This file merges raw data sets and creates the extended data set
* Inpute files: final_data.dta in subdirectory '../data/' - ADJUST AS FINAL STEP
* Output files: WR_dataset.dta in subdirectory '../data/' - ADJUST AS FINAL STEP
*
* Notes:
* - To run the code, please adjust line 25 and line 36.
*
* ------------------------------------------------------------------------------

* Housekeeping
clear all
set more off

* ADJUST AS FINAL STEP: Adjust path to base directory 
*global basedirectory  "../ReplicationPackage"

* For Windows, change to "\"
*global SLASH "/"

* Relative paths to subdirectories
*global data 	"${basedirectory}${SLASH}data"
*global tables 	"${basedirectory}${SLASH}output${SLASH}tables${SLASH}"
*global figures	"${basedirectory}${SLASH}output${SLASH}figures${SLASH}"

* Load data
*use "${data}${SLASH}final_data.dta", clear

* --------------------------
* Global for working folders - REMOVE AS FINAL STEP
global WR  "/Users/hannusch/Dropbox/ Research/Marshall Lecture/Data/A_FinalData/Women's Rights Replication 2023-01-23"
global data	"$WR/data"
 
cap log close
log using "$data/1_data_prep", replace

* ------------------------------------------------------------------------------
* 1. Data on abortion rights from Boyle et al. (2015) 
* ------------------------------------------------------------------------------

* Source: Data provided by Boyle et al. (2015) 

use "$data/rawdata/data_boyle_et_al_2015.dta", replace
rename stateabb wbcodev2

* Recode country codes to match WBL dataset (see 2.)

replace wbcodev2="DZA" if wbcodev2=="ALG" // Algeria
replace wbcodev2="AGO" if wbcodev2=="ANG" // Angola
replace wbcodev2="AUT" if wbcodev2=="AUS" // Austria
replace wbcodev2="ATG" if wbcodev2=="AAB" // Antigua
replace wbcodev2="BHS" if wbcodev2=="BHM" // Bahamas
replace wbcodev2="BHR" if wbcodev2=="BAH" // Bahrain
replace wbcodev2="BGD" if wbcodev2=="BNG" // Bangladesh
replace wbcodev2="BRB" if wbcodev2=="BAR" // Barbados
replace wbcodev2="BTN" if wbcodev2=="BHU" // Buthan
replace wbcodev2="BIH" if wbcodev2=="BOS" // Bosnia and Hezegovina
replace wbcodev2="BWA" if wbcodev2=="BOT" // Botswana
replace wbcodev2="BRN" if wbcodev2=="BRU" // Brunei (Darussalam)
replace wbcodev2="BGR" if wbcodev2=="BUL" // Bulgaria
replace wbcodev2="BFA" if wbcodev2=="BFO" // Burkina Faso
replace wbcodev2="BDI" if wbcodev2=="BUI" // Burundi
replace wbcodev2="CPV" if wbcodev2=="CAP" // Cap Verde
replace wbcodev2="KHM" if wbcodev2=="CAM" // Cambodia 
replace wbcodev2="CMR" if wbcodev2=="CAO" // Cameroon
replace wbcodev2="CAF" if wbcodev2=="CEN" // Central African Republic
replace wbcodev2="TCD" if wbcodev2=="CHA" // Chad
replace wbcodev2="COD" if wbcodev2=="DRC" // DR Congo
replace wbcodev2="COG" if wbcodev2=="CON" // Congo, Rep.
replace wbcodev2="CRI" if wbcodev2=="COS" // Costa Rica
replace wbcodev2="CIV" if wbcodev2=="CDI" // Cote d'Ivoire
replace wbcodev2="HRV" if wbcodev2=="CRO" // Croatia
replace wbcodev2="CZE" if wbcodev2=="CZR" // Czech Republic
replace wbcodev2="DNK" if wbcodev2=="DEN" // Denmark
replace wbcodev2="SLV" if wbcodev2=="SAL" // El Salvador
replace wbcodev2="GNQ" if wbcodev2=="EQG" // Equatorial Guinea
replace wbcodev2="FJI" if wbcodev2=="FIJ" // Fiji
replace wbcodev2="FRA" if wbcodev2=="FRN" // France
replace wbcodev2="GMB" if wbcodev2=="GAM" // Gambia
replace wbcodev2="GEO" if wbcodev2=="GRG" // Georgia
replace wbcodev2="DEU" if wbcodev2=="GMY" // Germany
replace wbcodev2="GTM" if wbcodev2=="GUA" // Guatemala
replace wbcodev2="GIN" if wbcodev2=="GUI" // Guinea
replace wbcodev2="HTI" if wbcodev2=="HAI" // Haiti
replace wbcodev2="HND" if wbcodev2=="HON" // Honduras
replace wbcodev2="ISL" if wbcodev2=="ICE" // Iceland
replace wbcodev2="IDN" if wbcodev2=="INS" // Indonesia
replace wbcodev2="IRL" if wbcodev2=="IRE" // Ireland
replace wbcodev2="KAZ" if wbcodev2=="KZK" // Kazakhstan
replace wbcodev2="KOR" if wbcodev2=="ROK" // Korea, Rep.
replace wbcodev2="KWT" if wbcodev2=="KUW" // Kuwait
replace wbcodev2="KGZ" if wbcodev2=="KYR" // Kyrgyz Republic
replace wbcodev2="LVA" if wbcodev2=="LAT" // Latvia
replace wbcodev2="LBN" if wbcodev2=="LEB" // Lebanon
replace wbcodev2="LSO" if wbcodev2=="LES" // Lesotho
replace wbcodev2="LTU" if wbcodev2=="LIT" // Lithuania
replace wbcodev2="MDG" if wbcodev2=="MAG" // Madagascar
replace wbcodev2="MWI" if wbcodev2=="MAW" // Malawi
replace wbcodev2="MYS" if wbcodev2=="MAL" // Malaysia
replace wbcodev2="MHL" if wbcodev2=="MSI" // Marshall Islands
replace wbcodev2="MRT" if wbcodev2=="MAA" // Mauritania
replace wbcodev2="MUS" if wbcodev2=="MAS" // Mauritius
replace wbcodev2="MDA" if wbcodev2=="MLD" // Moldova
replace wbcodev2="MCO" if wbcodev2=="MNC" // Monaco -- to fit WDI indicators
replace wbcodev2="MNG" if wbcodev2=="MON" // Mongolia 
replace wbcodev2="MAR" if wbcodev2=="MOR" // Morocco
replace wbcodev2="MMR" if wbcodev2=="MYA" // Myanmar
replace wbcodev2="NRU" if wbcodev2=="NAU" // Nauru -- to fit WDI indicators
replace wbcodev2="NPL" if wbcodev2=="NEP" // Nepal
replace wbcodev2="NLD" if wbcodev2=="NTH" // Netherlands
replace wbcodev2="NZL" if wbcodev2=="NEW" // New Zealand
replace wbcodev2="NER" if wbcodev2=="NIR" // Niger
replace wbcodev2="OMN" if wbcodev2=="OMA" // Oman
replace wbcodev2="PLW" if wbcodev2=="PAL" // Palau
replace wbcodev2="PRY" if wbcodev2=="PAR" // Paraguay
replace wbcodev2="PHL" if wbcodev2=="PHI" // Philippines
replace wbcodev2="PRT" if wbcodev2=="POR" // Portugal
replace wbcodev2="SMR" if wbcodev2=="SNM" // San Marino
replace wbcodev2="SYC" if wbcodev2=="SEY" // Seychelles
replace wbcodev2="SGP" if wbcodev2=="SIN" // Singapore
replace wbcodev2="SVK" if wbcodev2=="SLO" // Slovak Republic 
replace wbcodev2="SLB" if wbcodev2=="SOL" // Solomon Islands
replace wbcodev2="ZAF" if wbcodev2=="SAF" // South Africa
replace wbcodev2="LKA" if wbcodev2=="SRI" // Sri Lanka
replace wbcodev2="KNA" if wbcodev2=="SKN" // St. Kitts and Nevis
replace wbcodev2="LCA" if wbcodev2=="SLU" // St. Lucia
replace wbcodev2="VCT" if wbcodev2=="SVG" // St. Vincent and the Grenadines
replace wbcodev2="SDN" if wbcodev2=="SUD" // Sudan 
replace wbcodev2="SWZ" if wbcodev2=="SWA" & statenme=="Swaziland" // Swaziland / Eswatini
replace wbcodev2="CHE" if wbcodev2=="SWZ" & statenme=="Switzerland" // Switzerland
replace wbcodev2="SWE" if wbcodev2=="SWD" // Sweden
replace wbcodev2="TJK" if wbcodev2=="TAJ" // Tajikistan
replace wbcodev2="TZA" if wbcodev2=="TAZ" // Tanzania
replace wbcodev2="THA" if wbcodev2=="THI" // Thailand
replace wbcodev2="TGO" if wbcodev2=="TOG" // Togo
replace wbcodev2="TTO" if wbcodev2=="TRI" // Trinidad and Tobago
replace wbcodev2="ARE" if wbcodev2=="UAE" // United Arab Emirates
replace wbcodev2="GBR" if wbcodev2=="UKG" // United Kingdom
replace wbcodev2="URY" if wbcodev2=="URU" // Uruguay
replace wbcodev2="VUT" if wbcodev2=="VAN" // Vanuatu
replace wbcodev2="ZMB" if wbcodev2=="ZAM" // Zambia
replace wbcodev2="ZWE" if wbcodev2=="ZIM" // Zimbabwe

label var lifen		"Abortion to save a woman's life"
label var phealthn	"Abortion to preserce a woman's physical health"
label var mhealthn	"Abortion to preserve a woman's mental health"
label var rapen		"Abortion in case of rape"
label var foetaln	"Abortion because of foetal impairment"
label var econsocn	"Abortion for economic or social reasons"
label var demandn	"Abortion on request"

rename (catholic buddhist muslim) (catholic_boyle buddhist_boyle muslim_boyle) 

* In WBL, the countries that previously formed Yugoslavia are coded separately: 
* Bosnia and Herzegovina, Croatia, Montenegro, North Macedonia, Serbia, Slovenia
* In line 186ff., we replace values for these countries prior to 2003 with Yugoslavia 
 
* ------------------------------------------------------------------------------
* 2. Women, Business and the Law Data for 1971-2022
* ------------------------------------------------------------------------------

* Source: https://wbl.worldbank.org/content/dam/sites/wbl/documents/2021/02/WBL1971-2022%20Dataset.dta

* Note: We cannot match data on abortion rights for the following 8 countries: 
* AND, CUB, LIE, MCO, NRU, PRK, TKM

merge 1:1 wbcodev2 year using "$data/rawdata/WBL1971-2022 Dataset.dta"

drop if _merge==1
drop _merge


* ------------------------------------------------------------------------------
* 3. World Development Indicators
* ------------------------------------------------------------------------------

* Source: https://databank.worldbank.org/source/world-development-indicators#

* Note: Taiwan is not listed as a separate country in the WDI database
* https://datahelpdesk.worldbank.org/knowledgebase/articles/114933-where-are-your-data-on-taiwan

* All other countries from the data set 'WBL1971-2022 Dataset.dta' are matched

preserve
	import excel "$data/rawdata/Data_Extract_From_World_Development_Indicators.xlsx", sheet("Data") firstrow clear
	drop if CountryCode==""
	forval x=1960/2021 {
		replace YR`x'="" if YR`x'==".."
	}
	replace SeriesCode=subinstr(SeriesCode, ".", "_", .) 
	export delimited using "$data/rawdata/data_WDI.csv", replace

	tempfile WDI
	import delimited "$data/rawdata/data_WDI.csv", clear // numerical formatting
	reshape long yr , i(countrycode seriescode) j(year)
	drop seriesname
	rename countryname country
	replace country="Turkey" if country=="Turkiye" 
	replace country="Czech Republic" if country=="Czechia"
	reshape wide yr , i(countrycode year) j(seriescode) string
	rename (yr*) (*)
	rename countrycode wbcodev2

	label var NY_GDP_PCAP_KD 		"GDP per capita (constant 2015 US$)"
	label var SE_SEC_ENRR 			"Secondary school enrollment"
	label var SG_GEN_PARL_ZS 		"Proportion of seats held by women in national parliaments (%)"
	label var SL_AGR_EMPL_ZS 		"Employment in agriculture"
	label var SL_TLF_ACTI_FE_ZS 	"Labor force participation rate, female (% of female population ages 15-64) (modeled ILO estimate)"
	label var SP_DYN_TFRT_IN 		"Fertility rate, total (births per woman)"
	label var SP_POP_TOTL_MA_ZS		"Population, male (% of total population)"
	
	save `WDI'
restore

merge 1:1 wbcodev2 year using `WDI'
drop if _merge==2
drop _merge

replace country="Taiwan, China" if wbcodev2=="TWN"


* ------------------------------------------------------------------------------
* 4. Data on female suffrage and women in parliament
* ------------------------------------------------------------------------------

* Source for female suffrage: Skaaning et al. (2015)
* Download data here: https://dataverse.harvard.edu/dataset.xhtml?persistentId=doi:10.7910/DVN/29106

* Source for women in parliament: Paxton et al. (2008)
* Download data here: https://www.icpsr.umich.edu/web/ICPSR/studies/24340/summary

preserve

	* Female suffrage (Skaaning et al., 2015)
		
	tempfile skaaning
	
	import excel "$data/rawdata/lied_v5.2.xls", sheet("Ark1") firstrow clear
	rename countryn country

	replace country="Iran, Islamic Rep." if country=="Iran"
	bysort country year: gen n=_n
	drop if country=="Japan" & year==2018 & n==2
	drop n
	keep country year female_suffrage

	label var female_suffrage	""
	save `skaaning'
	
	* Women in parliament, standing for election (Paxton et al., 2008)
	use "$data/rawdata/24340-0001-Data.dta", clear	
	
	replace COUNTRYN = "Brunei" if COUNTRYN=="Brunei Darussalam"
	replace COUNTRYN = "Congo Brazzaville" if COUNTRYN=="Congo"
	replace COUNTRYN = "Korea, South" if COUNTRYN=="Republic of Korea"
	replace COUNTRYN = "Korea, North" if COUNTRYN=="Democratic People's Republic of Korea"
	replace COUNTRYN = "Congo, Democratic Republic" if COUNTRYN=="Democratic Republic of the Congo"
	replace COUNTRYN = "Yemen, South" if COUNTRYN=="Democratic Yemen"
	replace COUNTRYN = "Yemen, North" if COUNTRYN=="Yemen Arab Republic"
	replace COUNTRYN = "Germany, West" if COUNTRYN=="Federal Republic of Germany"
	replace COUNTRYN = "Germany, East" if COUNTRYN=="German Democratic Republic"
	replace COUNTRYN = "Iran, Islamic Rep." if COUNTRYN=="Iran (Islamic Republic of)"
	replace COUNTRYN = "Laos" if COUNTRYN=="Lao People's Democratic Republic"
	replace COUNTRYN = "Libya" if COUNTRYN=="Libyan Arab Jamahiriya"
	replace COUNTRYN = "Micronesia" if COUNTRYN=="Micronesia (Federated States of)"
	replace COUNTRYN = "Vietnam, North" if COUNTRYN=="North Vietnam"
	replace COUNTRYN = "Moldova" if COUNTRYN=="Republic of Moldova"
	replace COUNTRYN = "Russia" if COUNTRYN=="Russian Federation"
	replace COUNTRYN = "St. Kitts and Nevis" if COUNTRYN=="Saint Kitts and Nevis"
	replace COUNTRYN = "St. Lucia" if COUNTRYN=="Saint Lucia"
	replace COUNTRYN = "St. Vincent and the Grenadines" if COUNTRYN=="Saint Vincent and the Grenadines"
	replace COUNTRYN = "Serbia-Montenegro" if COUNTRYN=="Serbia and Montenegro"
	replace COUNTRYN = "Yugoslavia" if COUNTRYN=="Socialist Federal Republic of Yugoslavia"
	replace COUNTRYN = "Syria" if COUNTRYN=="Syrian Arab Republic"
	replace COUNTRYN = "Macedonia" if COUNTRYN=="The former Yugoslav Republic of Macedonia"
	replace COUNTRYN = "United Kingdom" if COUNTRYN=="United Kingdom of Great Britain and Northern Irela"
	replace COUNTRYN = "Tanzania" if COUNTRYN=="United Republic of Tanzania"
	replace COUNTRYN = "United States" if COUNTRYN=="United States of America"
	replace COUNTRYN = "Vietnam" if COUNTRYN=="Viet Nam"
	replace COUNTRYN = "Vietnam, South" if COUNTRYN=="South Vietnam"

	rename *, lower
	rename countryn country
	reshape long p , i(country) j(year)
	keep country year thresh20 univstand

	label var thresh20	"Year country first attained 20% women"
	label var univstand	"Year in which right to stand for election was granted to all women"
	
	merge 1:1 country year using `skaaning'
	drop _merge
	
	tempfile skaaning_paxton
	
	replace country="Bahamas, The" if country=="Bahamas"
	replace country="Congo, Dem. Rep." if country=="Congo, Democratic Republic"
	replace country="Egypt, Arab Rep." if country=="Egypt"
	replace country="Gambia, The" if country=="Gambia"
	replace country="Korea, Rep." if country=="Korea, South"
	replace country="Korea, Dem. People's Rep." if country=="Korea, North"
	replace country="Kyrgyz Republic" if country=="Kyrgyzstan"
	replace country="Lao PDR" if country=="Laos"
	replace country="Russian Federation" if country=="Russia"
	replace country="Yemen, Rep." if country=="Yemen" 
	replace country="Brunei Darussalam" if country=="Brunei"
	replace country="Cabo Verde" if country=="Cape Verde"
	replace country="Congo, Rep." if country=="Congo Brazzaville"
	replace country="Eswatini" if country=="Swaziland"
	replace country="Micronesia, Fed. Sts." if country=="Micronesia"
	replace country="Slovak Republic" if country=="Slovakia"
	replace country="Syrian Arab Republic" if country=="Syria"
	replace country="Taiwan, China" if country=="Taiwan"
	replace country="Venezuela, RB" if country=="Venezuela"
	replace country="Timor-Leste" if country=="East Timor"
	replace country="North Macedonia" if country=="Macedonia" 
	
	label var female_suffrage "Female suffrage"
	
	save `skaaning_paxton'
	
restore

merge 1:1 country year using `skaaning_paxton' 

* Infer female suffrage (Skaaning data) regulations from 1970 onwards for countries that formed part of specific unions from the unions' female suffrage legislation:

	gen missing_suffrage=1 if female_suffrage==.
		
	* 1. USSR member countries until 1990: Armenia, Azerbaijan, Belarus, Estonia, Georgia, Kazakhstan, Kyrgyz Republic, Latvia, Lithuania, Moldova, Russian Federation, 			
	*		Tajikistan, Turkmenistan, Ukraine, and Uzbekistan
	* Source: https://www.britannica.com/place/Soviet-Union	
	gen USSR=female_suffrage if country=="USSR"
	bysort year: egen fem_suff_USSR=max(USSR)
	replace female_suffrage=fem_suff_USSR if year>=1970 & year<=1990 & (country=="Armenia" | country=="Azerbaijan" | country=="Belarus" | country=="Estonia" | country=="Georgia" | ///
		country=="Kazakhstan" | country=="Kyrgyz Republic" | country=="Latvia" | country=="Lithuania" | country=="Moldova" | country=="Russian Federation" | country=="Tajikistan" | ///
		country=="Turkmenistan" | country=="Ukraine" | country=="Uzbekistan") & missing_suffrage==1
	
	* 2. Czechslovakia until 1992: Czech republic, Slovak Republic
	* Source: https://www.britannica.com/place/Czechoslovakia
	gen Czech=female_suffrage if country=="Czechoslovakia"
	bysort year: egen fem_suff_Czech=max(Czech)
	replace female_suffrage=fem_suff_Czech if year>=1970 & year<=1992 & (country=="Czech Republic" | country=="Slovak Republic") & missing_suffrage==1
	
	* 3. Member countries of Yugoslavia until 1991: Bosnia and Herzegovina, Croatia, Montenegro, North Macedonia, Serbia (incl. Kosovo), Slovenia
	* Source: https://www.britannica.com/place/Yugoslavia-former-federated-nation-1929-2003
	gen Yugosl=female_suffrage if country=="Yugoslavia"
	bysort year: egen fem_suff_Yugosl=max(Yugosl)
	replace female_suffrage=fem_suff_Yugosl if year>=1970 & year<=1991 & (country=="Bosnia and Herzegovina" | country=="Croatia" | country=="Kosovo" | country=="Montenegro" | ///
		country=="North Macedonia" | country=="Serbia" | country=="Slovenia") & missing_suffrage==1
		
	* 4. Serbia-Montenegro, 1992-2005:
	* Source: https://www.britannica.com/place/Montenegro
	gen Serbia=female_suffrage if country=="Serbia-Montenegro"
	bysort year: egen fem_suff_Serbia=max(Serbia)
	replace female_suffrage=fem_suff_Serbia if year>=1992 & year<=2005 & (country=="Kosovo" | country=="Serbia" | country=="Montenegro") & missing_suffrage==1
	
	* 5. Kosovo, as part of Serbia, 2006-2007:
	* Source: https://www.britannica.com/place/Kosovo
	gen Kosovo=female_suffrage if country=="Serbia"
	bysort year: egen fem_suff_Kosovo=max(Kosovo)
	replace female_suffrage=fem_suff_Kosovo if year>=2006 & year<=2007 & country=="Kosovo" & missing_suffrage==1
	
	* 6. Namibia under South African rule, until 1989
	* Source: https://www.britannica.com/place/Namibia
	gen Namibia=female_suffrage if country=="South Africa"
	bysort year: egen fem_suff_Namibia=max(Namibia)
	replace female_suffrage=fem_suff_Namibia if year>=1970 & year<=1989 & country=="Namibia" & missing_suffrage==1
	
	* 7. Union of Eritrea and Ethiopia, until 1992
	* Source: https://www.britannica.com/place/Eritrea/Federation-with-Ethiopia
	gen Eritrea=female_suffrage if country=="Ethiopia"
	bysort year: egen fem_suff_Eritrea=max(Eritrea)
	replace female_suffrage=fem_suff_Eritrea if year>=1970 & year<=1992 & country=="Eritrea" & missing_suffrage==1
	
	* 8. Sudan and South Sudan, until 2010
	gen Sudan=female_suffrage if country=="Sudan"
	bysort year: egen fem_suff_Sudan=max(Sudan)
	replace female_suffrage=fem_suff_Sudan if year>=1970 & year<=2010 & country=="South Sudan" & missing_suffrage==1
	
	* 9. Germany before 1990 (according to Skaaning data, female suffrage existed in East and West)
	replace female_suffrage=1 if country=="Germany" & year>=1970 & year<=1989 & missing_suffrage==1
	
	* 10. Vietnam, 1970-1974 (according to Skaaning data, female suffrage existed in North and South)
	replace female_suffrage=1 if country=="Vietnam" & year>=1970 & year<=1974 & missing_suffrage==1
	
	* Allocation flag
	gen female_suffrage_flag=0 if female_suffrage!=.
	replace female_suffrage_flag=1 if female_suffrage!=. & missing_suffrage==1
	label var female_suffrage_flag "Allocation flag Female suffrage"
	label define female_suffrage_flag_val 0 "Not allocated" 1 "Allocated"
	label val female_suffrage_flag female_suffrage_flag_val
	
	drop missing_suffrage USSR fem_suff_USSR Czech fem_suff_Czech Yugosl fem_suff_Yugosl ///
		Serbia fem_suff_Serbia Kosovo fem_suff_Kosovo Namibia fem_suff_Namibia Eritrea fem_suff_Eritrea Sudan ///
		fem_suff_Sudan 

drop if _merge==2
drop _merge


* ------------------------------------------------------------------------------
* 5. Data on religious groups
* ------------------------------------------------------------------------------

* Source: https://clinecenter.illinois.edu/project/Religious-Ethnic-Identity/composition-religious-and-ethnic-groups-creg-project
* For documentation, check: https://uofi.app.box.com/s/ayrhyzii5rp27lubg19ild2q0bpsxrmg
* Note: The data provides information on religious shares until 2013. However, the center is
*       currently working on an updated version of the data. Please check their website 
*       for the extended version. 

preserve

	tempfile religion
	
	import delimited "$data/rawdata/ReligiousGroupsWide_v1.02.csv", clear

	replace country="Bosnia and Herzegovina" if country=="Bosnia-Herzegovina"
	replace country="Cabo Verde" if country=="Cape Verde"
	replace country="Congo, Rep." if country=="Congo"
	replace country="Congo, Dem. Rep." if country=="Democratic Republic of Congo"
	replace country="Timor-Leste" if country=="East Timor"
	replace country="Egypt, Arab Rep." if country=="Egypt"
	replace country="Gambia, The" if country=="Gambia"
	replace country="Germany, East" if country=="German Democratic Republic"
	replace country="Germany, West" if country=="German Federal Republic"
	replace country="Iran, Islamic Rep." if country=="Iran"
	replace country="Lao PDR" if country=="Laos"
	replace country="Korea, Rep." if country=="Republic of Korea"
	replace country="Romania" if country=="Rumania"
	replace country="Russian Federation" if country=="Russia"
	replace country="Slovak Republic" if country=="Slovakia"
	replace country="Eswatini" if country=="Swaziland"
	replace country="Syrian Arab Republic" if country=="Syria"
	replace country="Taiwan, China" if country=="Taiwan"
	replace country="United States" if country=="United States of America"
	replace country="Venezuela, RB" if country=="Venezuela"
	replace country="Yemen, North" if country=="Yemen Arab Republic"
	replace country="Yemen, South" if country=="Yemen PDR"
	replace country="North Macedonia" if country=="Macedonia"
	
	save `religion'
	
restore

merge 1:1 country year using `religion'
drop if _merge==2
drop _merge

 
* ------------------------------------------------------------------------------
* 6. Data on contraceptive prevalence
* ------------------------------------------------------------------------------

* Source: https://population.un.org/dataportal/home
* Indicator: Contraceptive prevalence (any method), Married or in a union women, 15-49, Median
 
preserve

	tempfile contraception
	
	import delimited "$data/rawdata/unpopulation_dataportal_20221112104252.csv", clear 
	rename value contraception_married
	rename location country
	rename iso3 wbcodev2
	rename time year	

	keep country wbcodev2 year contraception_married	

	replace country="Bahamas, The" if country=="Bahamas"
	replace country="Bolivia" if country=="Bolivia (Plurinational State of)"
	replace country="Hong Kong SAR, China" if country=="China, Hong Kong SAR"
	replace country="Taiwan, China" if country=="China, Taiwan Province of China"
	replace country="Congo, Rep." if country=="Congo"
	replace country="Czech Republic" if country=="Czechia"
	replace country="Cote d'Ivoire" if country=="Côte d'Ivoire"
	replace country="Korea, Dem. People's Rep." if country=="Dem. People's Rep. of Korea"
	replace country="Congo, Dem. Rep." if country=="Dem. Rep. of the Congo"
	replace country="Egypt, Arab Rep." if country=="Egypt"
	replace country="Gambia, The" if country=="Gambia"
	replace country="Iran, Islamic Rep." if country=="Iran (Islamic Republic of)"
	replace country="Kyrgyz Republic" if country=="Kyrgyzstan"
	replace country="Lao PDR" if country=="Lao People's Dem. Republic"
	replace country="Korea, Rep." if country=="Republic of Korea"
	replace country="St. Kitts and Nevis" if country=="Saint Kitts and Nevis"
	replace country="St. Lucia" if country=="Saint Lucia"
	replace country="St. Vincent and the Grenadines" if country=="Saint Vincent and the Grenadines"
	replace country="Slovak Republic" if country=="Slovakia"
	replace country="Tanzania" if country=="United Republic of Tanzania"
	replace country="Turkey" if country=="Türkiye"
	replace country="United States" if country=="United States of America"
	replace country="Venezuela, RB" if country=="Venezuela (Bolivarian Republic of)"
	replace country="Vietnam" if country=="Viet Nam"
	replace country="Yemen, Rep." if country=="Yemen"
	replace country="Moldova" if country=="Republic of Moldova"
	replace country="West Bank and Gaza" if country=="State of Palestine"
	
	label var contraception_married "Percentage of married women using contraception"
	
	save `contraception'
	
restore

merge 1:1 country year using `contraception'
drop if _merge==2
drop _merge


* ------------------------------------------------------------------------------
* 7. Data provided by Ebetürk (2021)
* ------------------------------------------------------------------------------

* Source: Data provided by Ebetürk (2021)
* Indicators: Number of conventions ratified, Women INGOs

preserve

	tempfile ebetuerk
	
	use "$data/rawdata/data_ebetuerk_2021.dta", clear

	replace country="Bahamas, The" if country=="Bahamas"
	replace country="Bosnia and Herzegovina" if country=="Bosnia"
	replace country="Brunei Darussalam" if country=="Brunei"
	replace country="Central African Republic" if country=="Central African Rep"
	replace country="Congo, Dem. Rep." if country=="Congo DR/Zaire"
	replace country="Congo, Rep." if country=="Congo Rep/Br"
	replace country="Egypt, Arab Rep." if country=="Egypt/UAR"
	replace country="Ethiopia" if country=="Ethiopia/Abyssinia"
	replace country="Gambia, The" if country=="Gambia"
	replace country="Germany, East" if country=="German DR"
	replace country="Germany, West" if country=="German FR"
	replace country="Iran, Islamic Rep." if country=="Iran"
	replace country="Cote d'Ivoire" if country=="Ivory Coast"
	replace country="Korea, Rep." if country=="Korea "
	replace country="Kyrgyz Republic" if country=="Krygiz Rep"
	replace country="Liechtenstein" if country=="Lichtenstein"
	replace country="Luxembourg" if country=="Luxemburg"
	replace country="Micronesia, Fed. Sts." if country=="Micronesia,Fed.Sts."
	replace country="Russian Federation" if country=="Russia"
	replace country="Sri Lanka" if country=="SriLanka/Ceylon"
	replace country="Thailand" if country=="Thailand/Siam"
	replace country="Venezuela, RB" if country=="Venezuela,RB"
	replace country="Vietnam" if country=="Viet nam"
	replace country="Yemen, Rep." if country=="Yemen Rep"
	replace country="Marshall Islands" if country=="marshall Islands"
	replace country="North Macedonia" if country=="Macedonia"
	
	label var Contotal	"Nb.\ of Conventions Ratified"
	label var wmningo	"Women INGOs"
	
	save `ebetuerk'

restore

merge 1:1 country year using `ebetuerk'

drop if _merge==2
drop _merge


* ------------------------------------------------------------------------------
* 8. Data on Female LFP from ILOSTAT Labour Force Statistics (LFS)
* ------------------------------------------------------------------------------

* Source: https://www.ilo.org/shinyapps/bulkexplorer30/
* Indicator: Labour force participation rate by sex and age (%) - Annual

preserve

	tempfile ilo_flfp
	
	use "$data/rawdata/EAP_DWAP_SEX_AGE_RT_A-filtered-2022-11-02.dta", clear
	keep ref_area_label time obs_value
	rename obs_value FLFP_ilo_15_64
	rename time year
	rename ref_area_label country
	keep country year FLFP_ilo_15_64
	destring year, replace

	replace country="Bahamas, The" if country=="Bahamas"
	replace country="Gambia, The" if country=="Gambia"
	replace country="Samoa" if country=="American Samoa"
	replace country="Cabo Verde" if country=="Cape Verde"
	replace country="Congo, Rep." if country=="Congo"
	replace country="Congo, Dem. Rep." if country=="Congo, Democratic Republic of the"
	replace country="Czech Republic" if country=="Czechia"
	replace country="Cote d'Ivoire" if country=="Côte d'Ivoire"
	replace country="Egypt, Arab Rep." if country=="Egypt"
	replace country="Hong Kong SAR, China" if country=="Hong Kong, China"
	replace country="Iran, Islamic Rep." if country=="Iran, Islamic Republic of"
	replace country="Korea, Rep." if country=="Korea, Republic of"
	replace country="Kyrgyz Republic" if country=="Kyrgyzstan"
	replace country="Lao PDR" if country=="Lao People's Democratic Republic"
	replace country="Micronesia, Fed. Sts." if country=="Micronesia (Federated States of)"
	replace country="Moldova" if country=="Moldova, Republic of"
	replace country="West Bank and Gaza" if country=="Occupied Palestinian Territory"
	replace country="St. Kitts and Nevis" if country=="Saint Kitts and Nevis"
	replace country="St. Lucia" if country=="Saint Lucia"
	replace country="St. Vincent and the Grenadines" if country=="Saint Vincent and the Grenadines"
	replace country="Slovak Republic" if country=="Slovakia"
	replace country="Tanzania" if country=="Tanzania, United Republic of"
	replace country="Turkey" if country=="Türkiye"
	replace country="Venezuela, RB" if country=="Venezuela, Bolivarian Republic of"
	replace country="Vietnam" if country=="Viet Nam"
	replace country="Yemen, Rep." if country=="Yemen"
	
	label var FLFP_ilo_15_64 "Labor force participation rate, female (% of female population ages 15-64)"
	
	save `ilo_flfp'
	
restore

merge 1:1 country year using `ilo_flfp'
drop if _merge==2
drop _merge


* ------------------------------------------------------------------------------
* 9. Extension of data on abortion rights
* ------------------------------------------------------------------------------

* Download data for 2011, 2013 and 2015 here: https://esa.un.org/PopPolicy/wpp_datasets.aspx
*	- 2011_WPPDataset_ReproductiveHealthFamilyPlanning .xls (Column H: Grounds on which abortion is permitted)
*	- 2013_WPPDataset_ReproductiveHealthFamilyPlanning.xls (Column H: Grounds on which abortion is permitted)
*	- 2015_WPPDataset_Fertility_FP_RH.xls (Column L: Legal grounds on which abortion is permitted)

* Download data for 2017 here: https://www.un.org/development/desa/pd/data/world-population-policies
*	- undesa_pd_2017_abortion_laws_policies_country_dataset.xlsx (1.a. - 1.k.)
*	Coding of reasons:
*		- reason_1 = 1.a. To save a woman's life
*		- reason_2 = 1.c. To preserve a woman's physical health
*		- reason_3 = 1.d. To preserve a woman's mental health 
*		- reason_4 = yes if 1.f. In cases of incest or 1.g. In cases of rape = yes 
*		- reason_5 = 1.h. in cases of foetal impairment 
*		- reason_6 = 1.i. for economic or social reasons
*		- reason_7 = yes if 1.j. on request

* Combine files into country_panel_abortion_2011-2017.dta using panel.R

preserve

	tempfile abortion_data
	
	use "$data/rawdata/country_panel_abortion_2011-2017.dta", clear
	
	replace country="Bahamas, The" if country=="Bahamas"
	replace country="Bolivia" if country=="Bolivia (Plurinational State of)"
	replace country="Congo, Rep." if country=="Congo"
	replace country="Congo, Dem. Rep." if country=="Democratic Republic of the Congo"	
	replace country="Cote d'Ivoire" if country=="Côte d'Ivoire"
	replace country="Korea, Dem. People's Rep." if country=="Democratic People's Republic of Korea"
	replace country="Egypt, Arab Rep." if country=="Egypt"
	replace country="Gambia, The" if country=="Gambia"
	replace country="Iran, Islamic Rep." if country=="Iran (Islamic Republic of)"
	replace country="Kyrgyz Republic" if country=="Kyrgyzstan"
	replace country="Lao PDR" if country=="Lao People's Democratic Republic"
	replace country="Micronesia, Fed. Sts." if country=="Micronesia (Federated States of)"
	replace country="Korea, Rep." if country=="Republic of Korea"
	replace country="Moldova" if country=="Republic of Moldova"
	replace country="St. Kitts and Nevis" if country=="Saint Kitts and Nevis"
	replace country="St. Lucia" if country=="Saint Lucia"
	replace country="St. Vincent and the Grenadines" if country=="Saint Vincent and the Grenadines"	
	replace country="Slovak Republic" if country=="Slovakia"
	replace country="Tanzania" if country=="United Republic of Tanzania"
	replace country="United States" if country=="United States of America"
	replace country="Venezuela, RB" if country=="Venezuela (Bolivarian Republic of)"
	replace country="Vietnam" if country=="Viet Nam"
	replace country="Yemen, Rep." if country=="Yemen"	
	replace country="West Bank and Gaza" if country=="State of Palestine"	
	
	label var reason_1				"To save a woman's life"
	label var reason_2 				"To preserce a woman's physical health"
	label var reason_3 				"To preserve a woman's mental health"
	label var reason_4				"In case of rape or incest"
	label var reason_5				"Because of foetal impairment"
	label var reason_6				"For economic or social reasons"
	label var reason_7				"On request"
	
	save `abortion_data'
	
restore

merge 1:1 country year using `abortion_data'
drop if _merge==2
drop _merge


* ------------------------------------------------------------------------------
* 10. Government Effectivness - Data from Quality of Government
* ------------------------------------------------------------------------------

* Source: https://www.qogdata.pol.gu.se/data/qog_std_ts_jan22.dta
* Indicator: Government Effectiveness, Estimate

preserve

	tempfile QoG_data
	
	use "$data/rawdata/qog_std_ts_jan22.dta", clear
	keep ccodealp year wbgi_gee
	rename ccodealp wbcodev2
	
	label var wbgi_gee	"Government Effectiveness (QoG data)"
	
	save `QoG_data'
	
restore

merge 1:1 wbcodev2 year using `QoG_data'
drop if _merge==2
drop _merge


* ------------------------------------------------------------------------------
* 11. Save raw data as WR_dataset.dta
* ------------------------------------------------------------------------------

order wbcodev2 year

save "$data/WR_dataset.dta", replace

log close

* ------------------------------------------------------------------------------
* 								end of do-file
* ------------------------------------------------------------------------------
