* ------------------------------------------------------------------------------
*
*                       THE ECONOMICS OF WOMEN'S RIGHTS  
*
* ------------------------------------------------------------------------------
*
* by Michèle Tertilt, Matthias Doepke, Anne Hannusch and Laura Montenbruck
*
* This version: 2022-12-05
*
* This file replicates all regression tables in the paper, the appendix, 
* and the online appendix.
*
* Inpute file : final_data.dta in subdirectory '../data/'
*
* Output files: Data for Figures in subdirectory '../output/figures/'
*
* Notes:
* - To run the code, please adjust line 28 and line 31.
*
* ------------------------------------------------------------------------------

* Housekeeping
clear all
set more off

/*
* Adjust path to base directory
global basedirectory  "../ReplicationPackage"

* For Windows, change to "\"
global SLASH "/"

* Relative paths to subdirectories
global data 	"${basedirectory}${SLASH}data"
global figures	"${basedirectory}${SLASH}output${SLASH}figures${SLASH}"

* Load data
use "${data}${SLASH}WR_finaldata.dta", clear
*/
* --------------------------
* REMOVE AS FINAL STEP
global SLASH 	"/"
global WR  		"/Users/hannusch/Dropbox/ Research/Marshall Lecture/Data/A_FinalData/Women's Rights Replication 2023-01-23"
global data		"$WR${SLASH}data"
global tables 	"$WR${SLASH}output${SLASH}tables${SLASH}"
global figures	"$WR${SLASH}output${SLASH}figures${SLASH}"

 
use "$data${SLASH}WR_finaldata.dta", clear


* ------------------------------------------------------------------------------
* A. Create datasets for figures
* ------------------------------------------------------------------------------
preserve

* Data for Figure 4

drop if year<1970

collapse (mean) Economic_rights Political_rights Labor_rights Body_rights ///
, by(year)

keep year Economic_rights Political_rights Labor_rights Body_rights
 
outsheet using "$figures/IndicesOverTime.txt", replace


* Data for Figure 3 (Maps)
restore

* Reverse scaling of gdp_pc variable in regressions
gen log_gdp=log(gdp_pc*1000)
 
keep c_id wbcodev2 year log_gdp gdp_pc opec WBL_index Overall_rights
drop if year<1970
 
reshape wide log_gdp gdp_pc opec WBL_index Overall_rights, i(c_id wbcodev2) j(year) 

rename wbcodev2 iso_a3

keep  iso_a3 *1971 *1991 *2000 *2017

sort iso_a3

outsheet using "$figures/Overall_Index.txt", replace  

* ------------------------------------------------------------------------------
* 								end of do-file
* ------------------------------------------------------------------------------
